@@ -17,13 +17,13 @@ DONGLES_TO_SKIP = [
     '861579032390149', # not entirely sure why 
 ]
 
+S3_URL = '' # to be changeable by the user?
 
-def urlifier(dongle, drive_time):
+def urlifier(dongle_id, drive):
     """
-    Turns any dongle and drive time into a cabana url
+    Return a url for a drive.
     """
-    url = f"http://cl-cabana.eba-eez4uaij.eu-west-1.elasticbeanstalk.com/cabana/?route={dongle}%7C{drive_time}"
-    return url
+    return f'https://{S3_URL}.amazonaws.com/creationlabs-raw-data/{dongle_id}/{drive}'
 
 
 def get_lastest_file(dongle_id: str):
@@ -37,14 +37,12 @@ def get_lastest_file(dongle_id: str):
     bucket = s3_resource.Bucket(bucket_name)
 
     last_segment, last_complete_drive = get_selected_drives(None, s3_resource, bucket_name, dongle_id)
-    # 064b1a99381ec054 2021-09-09--16-31-00 
     drive = '--'.join(last_segment.drive.split('--')[:-1])
     return urlifier(last_segment.dongle_id, drive)
 
 
 def get_drives_df(s3_resource, bucket_name, dongle_id: str, filter=0):
     '''
-    TODO: this probably requires a significant refactoring.
     '''
     from dt.ext.aws_s3_list import s3list
 
